==> haskell-tasty-rerun-1.1.13-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-rerun
version: 1.1.13
id: tasty-rerun-1.1.13-HiThK568LYPBw622PoRiW9
key: tasty-rerun-1.1.13-HiThK568LYPBw622PoRiW9
license: BSD-3-Clause
copyright: Oliver Charles (c) 2014
maintainer: ollie@ocharles.org.uk
author: Oliver Charles
homepage: http://github.com/ocharles/tasty-rerun
synopsis: Run tests by filtering the test tree depending on the result of previous test
          runs
description:
    This ingredient adds the ability to run tests by first filtering the test tree
    based on the result of a previous test run. For example, you can use this to
    run only those tests that failed in the last run, or to run only tests that
    have been added since tests were last ran.
    .
    This ingredient is specifically an ingredient *transformer* - given a list of
    '\''Tasty.Ingredient'\''s, '\''rerunningTests'\'' adds the ability for all of these
    ingredients to run against a filtered test tree. This transformer can be
    applied as follows:
    .
    > import Test.Tasty
    > import Test.Tasty.Runners
    >
    > main :: IO ()
    > main =
    >   defaultMainWithIngredients
    >     [ rerunningTests [ listingTests, consoleTestReporter ] ]
    >     tests
    >
    > tests :: TestTree
    > tests = undefined
    .
    This ingredient adds three command line parameters:
    .
    [@--rerun-update@] If specified the results of this test run will be saved to
    the log file at @--rerun-log-file@. If the ingredient does not execute tests
    (for example, @--list-tests@ is used) then the log file will not be
    updated. This option is not enabled by default.  This option does not require
    a value.
    .
    [@--rerun-log-file@] The path to the log file to read previous test
    information from, and where to write new information to (if @--rerun-update@
    is specified). This option defaults to @.tasty-rerun-log@.
    .
    [@--rerun-filter@] Which filters to apply to the '\''Tasty.TestTree'\'' based on
    previous test runs. The value of this option is a comma separated list of the
    following options:
    .
    * @failures@: Only run tests that failed on the previous run.
    .
    * @exceptions@: Only run tests that threw an exception on the previous run.
    .
    * @new@: Only run tests that are new since the previous test run.
    .
    * @successful@: Only run tests that were successful in the previous run.
    .
    Multiple options can be combined and will be taken under disjunction - so
    @--rerun-filter=failures,exceptions@ will run only tests that failed *or*
    threw an exception on the last run.
    .
    Defaults to all filters, which means all tests will be ran.
category: Testing
abi: 1413d3c225b107de187d790ca376e344
exposed: True
exposed-modules:
    Test.Tasty.Ingredients.Rerun
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-rerun-1.1.13
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-rerun-1.1.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-rerun-1.1.13
hs-libraries: HStasty-rerun-1.1.13-HiThK568LYPBw622PoRiW9
depends:
    base-4.11.1.0 containers-0.5.11.0 mtl-2.2.2
    optparse-applicative-0.14.3.0-3858SIdIcA6IDhFDNu1Ke4
    reducers-3.12.3-67HU9M1L1qX3au6Ad5G4Gz
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG stm-2.4.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    tasty-1.1.0.3-FIVcWyFmwoz8YcurpeH6hw transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             optparse-applicative-0.14.3.0-3858SIdIcA6IDhFDNu1Ke4=aab631eb7769f669f53846ea7d62d855
             reducers-3.12.3-67HU9M1L1qX3au6Ad5G4Gz=40a37911dfe8f12e57f959b168d5a12d
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=ea4c73c7e93df299ddc7c8e477e863d6
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             tasty-1.1.0.3-FIVcWyFmwoz8YcurpeH6hw=dda03f3c16f751757f36e25981e6268e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html: /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-rerun-1.1.13-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-rerun
version: 1.1.13
id: tasty-rerun-1.1.13-7ExydF19f9Y1Rdr6kLov9A
key: tasty-rerun-1.1.13-7ExydF19f9Y1Rdr6kLov9A
license: BSD-3-Clause
copyright: Oliver Charles (c) 2014
maintainer: ollie@ocharles.org.uk
author: Oliver Charles
homepage: http://github.com/ocharles/tasty-rerun
synopsis: Run tests by filtering the test tree depending on the result of previous test
          runs
description:
    This ingredient adds the ability to run tests by first filtering the test tree
    based on the result of a previous test run. For example, you can use this to
    run only those tests that failed in the last run, or to run only tests that
    have been added since tests were last ran.
    .
    This ingredient is specifically an ingredient *transformer* - given a list of
    '\''Tasty.Ingredient'\''s, '\''rerunningTests'\'' adds the ability for all of these
    ingredients to run against a filtered test tree. This transformer can be
    applied as follows:
    .
    > import Test.Tasty
    > import Test.Tasty.Runners
    >
    > main :: IO ()
    > main =
    >   defaultMainWithIngredients
    >     [ rerunningTests [ listingTests, consoleTestReporter ] ]
    >     tests
    >
    > tests :: TestTree
    > tests = undefined
    .
    This ingredient adds three command line parameters:
    .
    [@--rerun-update@] If specified the results of this test run will be saved to
    the log file at @--rerun-log-file@. If the ingredient does not execute tests
    (for example, @--list-tests@ is used) then the log file will not be
    updated. This option is not enabled by default.  This option does not require
    a value.
    .
    [@--rerun-log-file@] The path to the log file to read previous test
    information from, and where to write new information to (if @--rerun-update@
    is specified). This option defaults to @.tasty-rerun-log@.
    .
    [@--rerun-filter@] Which filters to apply to the '\''Tasty.TestTree'\'' based on
    previous test runs. The value of this option is a comma separated list of the
    following options:
    .
    * @failures@: Only run tests that failed on the previous run.
    .
    * @exceptions@: Only run tests that threw an exception on the previous run.
    .
    * @new@: Only run tests that are new since the previous test run.
    .
    * @successful@: Only run tests that were successful in the previous run.
    .
    Multiple options can be combined and will be taken under disjunction - so
    @--rerun-filter=failures,exceptions@ will run only tests that failed *or*
    threw an exception on the last run.
    .
    Defaults to all filters, which means all tests will be ran.
category: Testing
abi: b208be82eef809a144df4fec644d4d17
exposed: True
exposed-modules:
    Test.Tasty.Ingredients.Rerun
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-rerun-1.1.13
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-rerun-1.1.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-rerun-1.1.13
hs-libraries: HStasty-rerun-1.1.13-7ExydF19f9Y1Rdr6kLov9A
depends:
    base-4.11.1.0 containers-0.5.11.0 mtl-2.2.2
    optparse-applicative-0.14.3.0-3858SIdIcA6IDhFDNu1Ke4
    reducers-3.12.3-1VvH19kmQ7HNgbffCa80m
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG stm-2.4.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    tasty-1.1.0.4-JVxQGtLb8FS2ZJgzdlYC9o transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             optparse-applicative-0.14.3.0-3858SIdIcA6IDhFDNu1Ke4=aab631eb7769f669f53846ea7d62d855
             reducers-3.12.3-1VvH19kmQ7HNgbffCa80m=228227fa79b84fd4980bb12550f3adb9
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=ea4c73c7e93df299ddc7c8e477e863d6
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             tasty-1.1.0.4-JVxQGtLb8FS2ZJgzdlYC9o=45655e1f87d1aadd2caf3019f95a0f8e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html: /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
